==> nextcloud-27.1.7p0.tgz: nextcloud/apps/comments/l10n/uk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментарі",
    "You commented" : "Ви прокоментували",
    "{author} commented" : "{author} прокоментував(-ла)",
    "You commented on %1$s" : "Ви прокоментували на %1$s",
    "You commented on {file}" : "Ви прокоментували {file}",
    "%1$s commented on %2$s" : "%1$s прокоментовано у %2$s",
    "{author} commented on {file}" : "{author} прокоментував(-ла) {file}",
    "<strong>Comments</strong> for files" : "З'явилися <strong>коментарі</strong> до файлів",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Вас згадали у \"{file}\" в коментарі, який було додано користувачем, якого було вилучено",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} згадав вас у коментарі до \"{file}\"",
    "Files app plugin to add comments to files" : "Плаґін до застосунку и\"Файли\" для додавання коментарів до файлів",
    "Edit comment" : "Редагувати коментар",
    "Delete comment" : "Вилучити коментар",
    "Cancel edit" : "Скасувати редагування",
    "New comment" : "Новий коментар",
    "Write a comment …" : "Додати коментар ...",
    "Post comment" : "Опублікувати коментар",
    "@ for mentions, : for emoji, / for smart picker" : "@ for згадування, : для емоційок, / для асистента з вибору",
    "Could not reload comments" : "Не вдалося перезавантажити коментарі",
    "No comments yet, start the conversation!" : "Тут можна додати коментарі",
    "No more messages" : "Більше жодних повідомлень",
    "Retry" : "Ще раз",
    "Failed to mark comments as read" : "Не вдалося позначити коментарі прочитаними",
    "Unable to load the comments list" : "Не вдалося завантажити список коментарів",
    "_1 new comment_::_{unread} new comments_" : ["{unread} новий коментар","{unread} нових коментарів","{unread} нових коментарів","{unread} нових коментарів"],
    "Comment" : "Коментар",
    "An error occurred while trying to edit the comment" : "Під час редагування коментаря сталася помилка",
    "Comment deleted" : "Коментар вилучено",
    "An error occurred while trying to delete the comment" : "Під час спроби вилучити коментар сталася помилка",
    "An error occurred while trying to create the comment" : "Під час створення коментаря сталася помилка",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Вас згадали в \"{file}\" у коментарі користувача, який згодом було видалено",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитаний коментар","%n непрочитаних коментарів","%n непрочитаних коментарів","%n непрочитаних коментарів"]
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/comments/l10n/uk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментарі",
    "You commented" : "Ви прокоментували",
    "{author} commented" : "{author} прокоментував(-ла)",
    "You commented on %1$s" : "Ви прокоментували на %1$s",
    "You commented on {file}" : "Ви прокоментували {file}",
    "%1$s commented on %2$s" : "%1$s прокоментовано у %2$s",
    "{author} commented on {file}" : "{author} прокоментував(-ла) {file}",
    "<strong>Comments</strong> for files" : "З'явилися <strong>коментарі</strong> до файлів",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Вас згадали у \"{file}\" в коментарі, який було додано користувачем, якого було вилучено",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} згадав вас у коментарі до \"{file}\"",
    "Files app plugin to add comments to files" : "Плаґін до застосунку и\"Файли\" для додавання коментарів до файлів",
    "Edit comment" : "Редагувати коментар",
    "Delete comment" : "Вилучити коментар",
    "Cancel edit" : "Скасувати редагування",
    "New comment" : "Новий коментар",
    "Write a comment …" : "Додати коментар ...",
    "Post comment" : "Опублікувати коментар",
    "@ for mentions, : for emoji, / for smart picker" : "@ згадати, : емоційки, / асистент вибору",
    "Could not reload comments" : "Не вдалося перезавантажити коментарі",
    "No comments yet, start the conversation!" : "Тут можна додати коментарі",
    "No more messages" : "Більше жодних повідомлень",
    "Retry" : "Ще раз",
    "Failed to mark comments as read" : "Не вдалося позначити коментарі прочитаними",
    "Unable to load the comments list" : "Не вдалося завантажити список коментарів",
    "_1 new comment_::_{unread} new comments_" : ["{unread} новий коментар","{unread} нових коментарів","{unread} нових коментарів","{unread} нових коментарів"],
    "Comment" : "Коментар",
    "An error occurred while trying to edit the comment" : "Під час редагування коментаря сталася помилка",
    "Comment deleted" : "Коментар вилучено",
    "An error occurred while trying to delete the comment" : "Під час спроби вилучити коментар сталася помилка",
    "An error occurred while trying to create the comment" : "Під час створення коментаря сталася помилка",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Вас згадали в \"{file}\" у коментарі користувача, який згодом було вилучено",
    "Write a message …" : "Написати повідомлення ...",
    "\"@\" for mentions, \":\" for emoji, \"/\" for smart picker" : "\"@\" згадати, \":\" емоційки, \"/\" асистент вибору",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитаний коментар","%n непрочитаних коментарів","%n непрочитаних коментарів","%n непрочитаних коментарів"]
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
